@@ -37,8 +37,12 @@
 #ifdef __alpha__
 extern int adjtimex(struct timex *);
 #else
+#ifdef __ia64__
+extern int adjtimex(struct timex *);
+#else
 _syscall1(int, adjtimex, struct timex *, txcp)
 #endif
+#endif
 int F_print = 0;
 
 #ifndef LOG_PATH
@@ -164,35 +168,35 @@ void
 usage(void)
 {
   char msg[]=
-"
-Usage: adjtimex  [OPTION]... 
-Mandatory or optional arguments to long options are mandatory or optional
-for short options too.
-
-Get/Set Kernel Time Parameters:
-       -p, --print               print values of kernel time variables
-       -t, --tick val            set the kernel tick interval in usec
-       -f, --frequency newfreq   set system clock frequency offset
-       -s, --singleshot adj      slew the system clock by adj usec
-       -o, --offset adj          add a time offset of adj usec
-       -m, --maxerror val        set maximum error (usec)
-       -e, --esterror val        set estimated error (usec)
-       -T, --timeconstant val    set phase locked loop time constant
-       -a, --adjust[=count]      set system clock parameters per CMOS 
-                                 clock or (with --review) log file
-
-Estimate Systematic Drifts:
-       -c, --compare[=count]     compare system and CMOS clocks
-       -i, --interval tim        set clock comparison interval (sec)
-       -l, --log[=file]          log current times to file
-           --host timeserver     query the timeserver
-       -w, --watch               get current time from user
-       -r, --review[=file]       review clock log file, estimate drifts
-       -u, --utc                 the CMOS clock is set to UTC
-
-Informative Output:
-           --help                print this help, then exit
-       -v, --version             print adjtimex program version, then exit
+"\n\
+Usage: adjtimex  [OPTION]... \n\
+Mandatory or optional arguments to long options are mandatory or optional\n\
+for short options too.\n\
+\n\
+Get/Set Kernel Time Parameters:\n\
+       -p, --print               print values of kernel time variables\n\
+       -t, --tick val            set the kernel tick interval in usec\n\
+       -f, --frequency newfreq   set system clock frequency offset\n\
+       -s, --singleshot adj      slew the system clock by adj usec\n\
+       -o, --offset adj          add a time offset of adj usec\n\
+       -m, --maxerror val        set maximum error (usec)\n\
+       -e, --esterror val        set estimated error (usec)\n\
+       -T, --timeconstant val    set phase locked loop time constant\n\
+       -a, --adjust[=count]      set system clock parameters per CMOS \n\
+                                 clock or (with --review) log file\n\
+\n\
+Estimate Systematic Drifts:\n\
+       -c, --compare[=count]     compare system and CMOS clocks\n\
+       -i, --interval tim        set clock comparison interval (sec)\n\
+       -l, --log[=file]          log current times to file\n\
+           --host timeserver     query the timeserver\n\
+       -w, --watch               get current time from user\n\
+       -r, --review[=file]       review clock log file, estimate drifts\n\
+       -u, --utc                 the CMOS clock is set to UTC\n\
+\n\
+Informative Output:\n\
+           --help                print this help, then exit\n\
+       -v, --version             print adjtimex program version, then exit\n\
 ";
 
   fputs(msg, stdout);
@@ -208,7 +212,8 @@ main(int argc, char *argv[])
 
     txc.modes = 0;
 
-    while((c = getopt_long_only(argc, argv, "", 
+    while((c = getopt_long_only(argc, argv, 
+				"a::c::l::e:f:h:i:m:o:prPPsPT:t:uvw", 
 				longopt, NULL)) != -1)
       {
 	switch(c)
